@@ -2,11 +2,13 @@
 
 """The machine engine"""
 
-from .misc import Bundler, Pipeline, collect_chunks, fs_changes
+from .misc import Bundler, PipedValue, PipeError, Pipeline, collect_chunks, fs_changes
 
 __all__ = [
     "Bundler",
     "Pipeline",
+    "PipedValue",
+    "PipeError",
     "fs_changes",
     "collect_chunks",
 ]
